@@ -124,7 +124,7 @@ class Client:
         try:
             url = self.__api_host + "/v1/leaf/logout"
 
-            resp = requests.put(url, auth=(self.__leaf_name, self.__access_token), verify=self.__verify)
+            resp = requests.put(url, auth=(self.__leaf_id, self.__access_token), verify=self.__verify)
 
             if resp.status_code != HTTPStatus.OK:
                 raise Exception(f"{resp.json()['message']}")
